@@ -6,7 +6,7 @@ class MonteCarlo:
     (OBJECT INFO)
     -------------
 
-    vandal.MonteCarlo - main class that defines the data, desired time sequence and number of simulations.
+    vandal.MonteCarlo - main class.
 
     (OBJECT FUNCTIONS)
     ------------------
@@ -14,16 +14,14 @@ class MonteCarlo:
     eg. vandal.MonteCarlo.function()
 
         .execute() - executes a Monte Carlo simulation on a defined data set.
-            * takes 5 additional arguments.
+            * takes 4 additional arguments.
             list_of_values - pandas dataframe of values.
             time_seq - desired time sequence.
             num_sims - desired number of simulation iterations.
             ref_value_index (default: ref_value_index = 0) - index on which the starting point of the simulation is created.
-            log_summary (default: log_summary = False) - event log of executed functions. - DEVELOPER MODE ONLY
         * Requirements:
             pandas Python module.
             pd.DataFrame() defined data set.
-        * automatically executes the .execute() function.
 
         .graph() - plots the Monte Carlo simulation on a graph.
             * takes 5 optional customization arguments. (default: graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True).
@@ -58,10 +56,8 @@ class MonteCarlo:
 
     Developer mode functions can only be set up manually by removing the '#DEVELOPER MODE -' in the source code.
 
-        .get_logs() - shows the event log of executed functions.
         * takes no additional arguments.
         * Requirements:
-            log_summary = True.
             '# DEVELOPER MODE -' removed in the code.
 
     '''
@@ -78,46 +74,35 @@ class MonteCarlo:
         __donate__,
     )
 
+    # import duality package decorators.
+    # DEVELOPER MODE -  from duality import track, record
+
     # initial launch.
+    # DEVELOPER MODE - @track.entry('init')
+    # DEVELOPER MODE - @record.entry(option_name = 'init', option_description = 'initial launch.')
     def __init__(self):
         pass
 
-    # DEVELOPER MODE - creates an event log that tracks the function execution time and duration.
-    def classLog(func_name):
-        def log(func):
-                import time
-                import datetime
-                def logsaver(self, *args, **kwargs):
-                    if self.log_summary == True:
-                        start = time.time()
-                        results = func(self, *args, **kwargs)
-                        with open('vandal Logs.txt', 'a') as f:
-                            f.write('Performed a function ' + func_name + ' at: ' + str(datetime.datetime.now()) + '.' + ' Time spent performing the action: ' + str(time.time() - start) + ' seconds.' + '\n')
-                            return results
-                    else:
-                            results = func(self, *args, **kwargs)
-                            return results
-                return logsaver
-        return log
-
-    # DEVELOPER MODE - @classLog('__str__()')
-    #class information.
+    # class information.
+    # DEVELOPER MODE - @track.entry('string')
+    # DEVELOPER MODE - @record.entry(option_name = 'string', option_description = 'class information.')
     def __str__(self):
         return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
 
-    # DEVELOPER MODE - @classLog('__repr__()')
     # class information.
+    # DEVELOPER MODE - @track.entry('representation')
+    # DEVELOPER MODE - @record.entry(option_name = 'repr', option_description = 'shows object details.')
     def __repr__(self):
         return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
 
-    # DEVELOPER MODE - @classLog('execute() - built in function.')
     # executes a Monte Carlo simulation on a defined data set.
-    def execute(self, list_of_values, time_seq, num_sims, ref_value_index = 0, log_summary = False):
+    # DEVELOPER MODE - @track.entry('execution')
+    # DEVELOPER MODE - @record.entry(option_name = 'execution', option_description = 'executes a Monte Carlo simulation on a defined data set.')
+    def execute(self, list_of_values, time_seq, num_sims, ref_value_index = 0):
         self.list_of_values = list_of_values
         self.time_seq = time_seq
         self.num_sims = num_sims
         self.ref_value_index = ref_value_index
-        self.log_summary = log_summary
         print(f'Monte Carlo has been set up for {self.num_sims} simulations in a period of {self.time_seq} time measurement units.')
         from vandal.hub.toolkit import random_value
         print('Monte Carlo simulation has been executed.')
@@ -160,13 +145,15 @@ class MonteCarlo:
         self.results = data
         return data
 
-    # DEVELOPER MODE - @classLog('get_change()')
-    #shows the percentage of Monte Carlo simulation value change for every iteration.
+    # shows the percentage of Monte Carlo simulation value change for every iteration.
+    # DEVELOPER MODE - @track.entry('change')
+    # DEVELOPER MODE - @record.entry(option_name = 'change', option_description = 'shows the percentage of Monte Carlo simulation value change for every iteration.')
     def get_change(self):
         return self.results.pct_change()
 
-    # DEVELOPER MODE - @classLog('get_risk()')
     # calculates the risk of negative values occuring.
+    # DEVELOPER MODE - @track.entry('risk')
+    # DEVELOPER MODE - @record.entry(option_name = 'risk', option_description = 'calculates the risk of negative values occuring.')
     def get_risk(self, risk_sims = 5000):
         import random
         import pandas as pd
@@ -195,8 +182,9 @@ class MonteCarlo:
 
         print('\nRisk for this option is', round(NRisk,2), '%.')
 
-    # DEVELOPER MODE - @classLog('graph()')
     # plots the Monte Carlo simulation on a graph.
+    # DEVELOPER MODE - @track.entry('graph')
+    # DEVELOPER MODE - @record.entry(option_name = 'graph', option_description = 'plots the Monte Carlo simulation on a graph.')
     def graph(self, graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True):
         print('\nMonteCarlo() plotting initialized.')
         import matplotlib.pyplot as plt
@@ -210,8 +198,9 @@ class MonteCarlo:
         plt.show(block = perform_block)
         print('MonteCarlo() plotting finished.')
 
-    # DEVELOPER MODE - @classLog('get_stats()')
     # shows the statistics of the Monte Carlo simulation.
+    # DEVELOPER MODE - @track.entry('statistics')
+    # DEVELOPER MODE - @record.entry(option_name = 'statistics', option_description = 'shows the statistics of the Monte Carlo simulation.')
     def get_stats(self, filtered = False):
         import numpy as np
         mean_value = np.mean(self.results.loc[self.time_seq])
@@ -232,8 +221,9 @@ class MonteCarlo:
             print('Maximum: ', maximum_value)
             print('Minimum: ', minimum_value, '\n')
 
-    # DEVELOPER MODE - @classLog('hist()')
     # plots the histogram of Monte Carlo simulation.
+    # DEVELOPER MODE - @track.entry('histogram')
+    # DEVELOPER MODE - @record.entry(option_name = 'histogram', option_description = 'plots the histogram of Monte Carlo simulation.')
     def hist(self, graph_title = 'Histogram of value frequencies', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True, **method):
         self.get_stats(filtered = True)
         std_plus = self.mean_value + self.standard_deviation
@@ -272,8 +262,16 @@ class MonteCarlo:
         plt.show(block = perform_block)
         print('Histogram plotting finished.')
 
-    # DEVELOPER MODE - @classLog('get_logs()')
-    # returns the saved logs of executed functions.
+    # DEVELOPER MODE - @record.display(method = 'dictionary')
+    # DEVELOPER MODE - @track.entry('menu')
+    # DEVELOPER MODE - @record.entry(option_name = 'menu', option_description = 'access saved menu particles from function execution.')
+    # access saved menu particles from function execution.  
+    def get_menu(self):
+        return
+
+    # DEVELOPER MODE - @track.display()
+    # DEVELOPER MODE - @track.entry('logs')
+    # DEVELOPER MODE - @record.entry(option_name = 'logs', option_description = 'access saved logs from function execution.')
+    # access saved logs from function execution.
     def get_logs(self):
-        f = open('vandal Logs.txt', 'r')
-        print(f.read())
+        return
